==> stack-2.9.3.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-FefpmNIKoiG4TdF4TxJMEY
key:                  stack-2.9.3.1-FefpmNIKoiG4TdF4TxJMEY
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  fae46d957bea75ec4d639a6b2446672e
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-FefpmNIKoiG4TdF4TxJMEY
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-JNQYc01xThWEgUAi55dqd4 array-0.5.4.0
    async-2.2.5-BbDohv985MkKG2Ydm62Fmc
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 casa-client-0.0.2-8GXNqPbf157FYNjb476KTh
    casa-types-0.0.2-DErKs91IwglENVKU90DSCB
    colour-2.3.6-2wv2ltb9NHWFgnG7RawbOn
    conduit-1.3.6.1-LX1OqlTDVgXB5T9goEDWxI
    conduit-extra-1.3.8-DMXEhav2zajAIstf73Tomd containers-0.6.7
    crypton-1.0.3-BOwwESl5wKY5wf5LQYyzlS
    crypton-conduit-0.2.3-BZjG0w4h2z1JesDPvjVty8 deepseq-1.4.8.0
    directory-1.3.7.1 echo-0.1.4-HrG6UGs9bUNIRHTRpjaAQ
    exceptions-0.10.5 extra-1.7.16-78p7g4t2O5F2wUG9XuP5u
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filelock-0.1.1.8-2vaTyYHpjUNEpCIodIIoB7 filepath-1.4.2.2
    fsnotify-0.4.4.0-EvxArYoihWU1s4hOq6KeWX
    generic-deriving-1.14.6-4rZ70qq0idRDuZRag0Nzqq
    hackage-security-0.6.3.1-IgDA4YpZsMDBQ28e7jmYu4
    hashable-1.4.5.0-46ofdJt9DgFJv5hpm4ccL9
    hi-file-parser-0.1.8.0-6xyDaOD9SFFEYUP6Bd4Csg
    hpack-0.36.1-6dfWqCgFhMfHegIw5k6cJe hpc-0.6.1.0
    http-client-0.7.19-IIytK7PBQn9EsqIfUwIiV
    http-client-tls-0.3.6.4-LGF2WOi7ToiLbJydJMsCzM
    http-conduit-2.3.9.1-LxnUn0ka277EnTyLVsMMao
    http-download-0.2.1.0-8i7HomveXRE3zZ7ovSRJYU
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    mintty-0.1.4-AuJ2EgpOQbhHDGkFzZNT4J
    mono-traversable-1.0.21.0-Fit1oCCmSHnAtmxsKpYSya mtl-2.2.2
    mustache-2.4.3.1-G1YtHpGzGnkKcJ9SIqLXn9
    neat-interpolation-0.5.1.4-1sOft3lo3dk6U8oLmD7BHg
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    open-browser-0.2.1.1-JxaFXLEqga6LFagqIfuNya
    optparse-applicative-0.18.1.0-CZp2uWBrZhVKrqP7dbntdc
    pantry-0.8.2-EMwr6kXCDRpFdGnvxhgM7X
    path-0.9.5-1fFUskDud6T5l6j44tPx6o
    path-io-1.8.2-CKz3LmxBdoz7qpWumtUekE
    persistent-2.14.5.2-EFwh713VBzoEXC9AExpOGQ
    persistent-sqlite-2.13.1.1-cOiQHQfDCuDPo6IGSRPgq pretty-1.1.3.6
    primitive-0.9.1.0-D2h8cSAG2AjKP2pRuhtPBO process-1.6.18.0
    project-template-0.2.1.0-J4hdUagRZbOLGweUHTODxD
    random-1.2.1.3-3lKZsy50ahFJstdbQE9KC3
    retry-0.9.3.1-BRnka5AbRj2FGu82uKxK2a
    rio-0.1.22.0-EQuf6tgBEUw8dj2omaNih1
    rio-prettyprint-0.1.8.0-K49ffFAMHcHNjHgE2PF72
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q stm-2.5.1.0
    streaming-commons-0.2.3.0-FJTLVTwdqrIIriz7H6jbG4
    tar-0.5.1.1-JXgKqaMAoYP3ZxTGJa73mo template-haskell-2.19.0.0
    temporary-1.3-GqTQQZxhgaKHMmG7i0IazO text-2.0.2
    text-metrics-0.3.3-1CZJo8pR0T34IH7CMUDOYi
    th-reify-many-0.1.10-2CdBKjqYJgV1oUyGVPz8uQ time-1.12.2
    tls-2.0.6-BHD3CnRn3tILeXp2dZgrJc transformers-0.5.6.2
    typed-process-0.2.13.0-8cng0JIuOm7KrxArbQNhe2
    unicode-transforms-0.4.0.1-KIS1dPaJ4LEIAYRyygpLEM unix-2.7.3
    unix-compat-0.7.4.1-7mIDBr1TancFwsGNESA8LC
    unliftio-0.2.25.1-CgePo7ngrPgLZdb5MfeeLl
    unordered-containers-0.2.20-9wNMaDmysQKAAHkxxaXhUB
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt
    yaml-0.11.11.2-DOTRoIN69iI8VkvsxHJhD8
    zip-archive-0.4.3.2-KgXyKJ9jWQkCt0vuELTes5
    zlib-0.7.0.0-5J8qtSnxQ9lBB7H0QqMVmL

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stack-2.9.3.1-59-x86_64.pkg.tar.zst: usr/share/haskell/register/stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-JVaZM7Kqsrh3D3O9UBj5t8
key:                  stack-2.9.3.1-JVaZM7Kqsrh3D3O9UBj5t8
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  7757b63b11d63a789c303d31aae0d527
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-JVaZM7Kqsrh3D3O9UBj5t8
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4
    annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
    ansi-terminal-1.0.2-JNQYc01xThWEgUAi55dqd4 array-0.5.4.0
    async-2.2.5-BbDohv985MkKG2Ydm62Fmc
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 casa-client-0.0.2-8GXNqPbf157FYNjb476KTh
    casa-types-0.0.2-DErKs91IwglENVKU90DSCB
    colour-2.3.6-2wv2ltb9NHWFgnG7RawbOn
    conduit-1.3.6.1-LX1OqlTDVgXB5T9goEDWxI
    conduit-extra-1.3.8-DMXEhav2zajAIstf73Tomd containers-0.6.7
    crypton-1.0.3-BOwwESl5wKY5wf5LQYyzlS
    crypton-conduit-0.2.3-BZjG0w4h2z1JesDPvjVty8 deepseq-1.4.8.0
    directory-1.3.7.1 echo-0.1.4-HrG6UGs9bUNIRHTRpjaAQ
    exceptions-0.10.5 extra-1.7.16-78p7g4t2O5F2wUG9XuP5u
    file-embed-0.0.16.0-FS79AECsQN660bIXAMLGHY
    filelock-0.1.1.8-2vaTyYHpjUNEpCIodIIoB7 filepath-1.4.2.2
    fsnotify-0.4.4.0-2BKdNXiIMzM2S4DQhh2KcY
    generic-deriving-1.14.6-4rZ70qq0idRDuZRag0Nzqq
    hackage-security-0.6.3.1-IgDA4YpZsMDBQ28e7jmYu4
    hashable-1.4.5.0-46ofdJt9DgFJv5hpm4ccL9
    hi-file-parser-0.1.8.0-6xyDaOD9SFFEYUP6Bd4Csg
    hpack-0.36.1-6dfWqCgFhMfHegIw5k6cJe hpc-0.6.1.0
    http-client-0.7.19-IIytK7PBQn9EsqIfUwIiV
    http-client-tls-0.3.6.4-LGF2WOi7ToiLbJydJMsCzM
    http-conduit-2.3.9.1-LxnUn0ka277EnTyLVsMMao
    http-download-0.2.1.0-8i7HomveXRE3zZ7ovSRJYU
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    mintty-0.1.4-AuJ2EgpOQbhHDGkFzZNT4J
    mono-traversable-1.0.21.0-Fit1oCCmSHnAtmxsKpYSya mtl-2.2.2
    mustache-2.4.3.1-G1YtHpGzGnkKcJ9SIqLXn9
    neat-interpolation-0.5.1.4-1sOft3lo3dk6U8oLmD7BHg
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    open-browser-0.2.1.1-JxaFXLEqga6LFagqIfuNya
    optparse-applicative-0.18.1.0-CZp2uWBrZhVKrqP7dbntdc
    pantry-0.8.2-EMwr6kXCDRpFdGnvxhgM7X
    path-0.9.5-1fFUskDud6T5l6j44tPx6o
    path-io-1.8.2-CKz3LmxBdoz7qpWumtUekE
    persistent-2.14.5.2-EFwh713VBzoEXC9AExpOGQ
    persistent-sqlite-2.13.1.1-cOiQHQfDCuDPo6IGSRPgq pretty-1.1.3.6
    primitive-0.9.1.0-D2h8cSAG2AjKP2pRuhtPBO process-1.6.18.0
    project-template-0.2.1.0-J4hdUagRZbOLGweUHTODxD
    random-1.2.1.3-3lKZsy50ahFJstdbQE9KC3
    retry-0.9.3.1-BRnka5AbRj2FGu82uKxK2a
    rio-0.1.22.0-EQuf6tgBEUw8dj2omaNih1
    rio-prettyprint-0.1.8.0-K49ffFAMHcHNjHgE2PF72
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q stm-2.5.1.0
    streaming-commons-0.2.3.0-FJTLVTwdqrIIriz7H6jbG4
    tar-0.5.1.1-JXgKqaMAoYP3ZxTGJa73mo template-haskell-2.19.0.0
    temporary-1.3-GqTQQZxhgaKHMmG7i0IazO text-2.0.2
    text-metrics-0.3.3-1CZJo8pR0T34IH7CMUDOYi
    th-reify-many-0.1.10-2CdBKjqYJgV1oUyGVPz8uQ time-1.12.2
    tls-2.0.6-BHD3CnRn3tILeXp2dZgrJc transformers-0.5.6.2
    typed-process-0.2.13.0-8cng0JIuOm7KrxArbQNhe2
    unicode-transforms-0.4.0.1-KIS1dPaJ4LEIAYRyygpLEM unix-2.7.3
    unix-compat-0.7.4.1-7mIDBr1TancFwsGNESA8LC
    unliftio-0.2.25.1-CgePo7ngrPgLZdb5MfeeLl
    unordered-containers-0.2.20-9wNMaDmysQKAAHkxxaXhUB
    vector-0.13.2.0-7UWGIXxclbLLOjGg0s2qXt
    yaml-0.11.11.2-DOTRoIN69iI8VkvsxHJhD8
    zip-archive-0.4.3.2-KgXyKJ9jWQkCt0vuELTes5
    zlib-0.7.0.0-5J8qtSnxQ9lBB7H0QqMVmL

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
